@@ -1,11 +1,15 @@
 package RTx::TicketlistTransactions;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 =head1 NAME
 
 RTx::TicketlistTransactions - Adds LastTransactionContent as a search display column
 
+=head1 RT VERSION
+
+Works with RT 4.0 and 4.2
+
 =head1 INSTALLATION 
 
 =over
@@ -20,7 +24,11 @@ May need root permissions
 
 =item Edit your /opt/rt4/etc/RT_SiteConfig.pm
 
-Add this line:
+If you are using RT 4.2 or greater, add this line:
+
+    Plugin('RTx::TicketlistTransactions');
+
+For RT 4.0, add this line:
 
     Set(@Plugins, qw(RTx::TicketlistTransactions));
 
@@ -54,7 +62,11 @@ Only textual content is displayed, any formatting will be stripped.
 
 =head1 LICENCE AND COPYRIGHT
 
-This software is copyright (c) 2011 by Best Practical Solutions.
+This software is copyright (c) 2011-2014 by Best Practical Solutions.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 2, June 1991
 
 =cut
 
